**pyscreenshot**

:Date: |today|
:PDF: `pyscreenshot.pdf <pyscreenshot.pdf>`_


Contents:

.. toctree::
    :maxdepth: 2

    readme
    struct
    examples
    speed
    help
    api
        
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

